@@ -39,7 +39,7 @@ void CFMan::dir_up()
 {
   if (dir.path() == "/")
      return;
-  
+
   QString oldcurdir = dir.dirName();
 
   dir.cdUp();
@@ -54,41 +54,48 @@ void CFMan::dir_up()
 
 void CFMan::nav (const QString &path)
 {
-  dir.setPath (path);
+  if (path.isEmpty())
+     return;
+
+  QString p = path;
+  if (path.startsWith ("file://"))
+     p = p.remove (0, 7);
+
+  dir.setPath (p);
   if (! dir.exists())
       return;
 
   setModel (0);
 
   QDir::SortFlags sort_flags = 0;
-  
+
   if (sort_order == Qt::DescendingOrder)
      sort_flags |= QDir::Reversed;
-  
+
   if (sort_mode == 0)
      sort_flags |= QDir::Name;
 
   if (sort_mode == 1)
      sort_flags |= QDir::Size;
-  
+
   if (sort_mode == 2)
      sort_flags |= QDir::Time;
 
   sort_flags |= QDir::DirsFirst;
   sort_flags |= QDir::IgnoreCase;
   sort_flags |= QDir::LocaleAware;
- 
-  
+
+
   mymodel->removeRows (0, mymodel->rowCount());
-  
+
   QFileInfoList lst = dir.entryInfoList (QDir::Dirs | QDir::Hidden | QDir::NoDotAndDotDot |
-                                         QDir::Files | QDir::Drives, 
+                                         QDir::Files | QDir::Drives,
                                          sort_flags);
 
-  
-  
+
+
   /*QFileInfoList lst = dir.entryInfoList (QDir::Dirs | QDir::Hidden | QDir::NoDotAndDotDot |
-                                         QDir::Files | QDir::Drives, 
+                                         QDir::Files | QDir::Drives,
                                          QDir::Name |
                                          QDir::DirsFirst | QDir::IgnoreCase | QDir::LocaleAware);
 
@@ -105,10 +112,10 @@ QDir::DirsLast 0x20  Put the files first, then the directories.
 QDir::Reversed 0x08  Reverse the sort order.
 QDir::IgnoreCase  0x10  Sort case-insensitively.
 QDir::LocaleAware 0x40  Sort items appropriately using the current locale settings.
-    
-    
+
+
    */
-  
+
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 
   if (path != "/")
@@ -123,10 +130,10 @@ QDir::LocaleAware 0x40  Sort items appropriately using the current locale settin
 
   foreach (QFileInfo fi, lst)
            add_entry (fi);
-          
+
   setModel (mymodel);
   connect (selectionModel(), SIGNAL(currentChanged (const QModelIndex &, const QModelIndex &)), this, SLOT(cb_fman_currentChanged (const QModelIndex &, const QModelIndex &)));
-  emit dir_changed (path);
+  emit dir_changed (p);
 }
 
 
@@ -144,20 +151,20 @@ const QModelIndex CFMan::index_from_name (const QString &name)
 void CFMan::tv_activated (const QModelIndex &index)
 {
   QString item_string = index.data().toString();
-  
+
   QString dpath = dir.path();
-  
+
   if (dpath.size() > 1)
      if (dpath.endsWith("/") || dpath.endsWith("\\"))
         dpath.truncate(dpath.size() - 1);
-    
+
   QString full_path;
-  
+
   if (dpath == "/")
      full_path = "/" + item_string;
   else
      full_path = dpath + "/" + item_string;
-  
+
   if (item_string == ".." && dir.path() != "/")
      {
       dir_up();
@@ -228,72 +235,57 @@ void CFMan::append_dot_entry (const QString &fname)
 
 void CFMan::header_view_sortIndicatorChanged (int logicalIndex, Qt::SortOrder order)
 {
-//  qDebug() << "header col = " << logicalIndex << " order = " << order; 
+//  qDebug() << "header col = " << logicalIndex << " order = " << order;
   sort_order = order;
   sort_mode = logicalIndex;
-  
+
   settings->setValue ("fman_sort_mode", sort_mode);
   settings->setValue ("fman_sort_order", sort_order);
-  
-  refresh();  
+
+  refresh();
 }
 
 
 CFMan::CFMan (QWidget *parent): QTreeView (parent)
 {
-//  sort_mode = 0;
-//  sort_order = Qt::AscendingOrder;
- 
-  sort_mode = settings->value ("fman_sort_mode", 0).toInt(); 
-  sort_order = Qt::SortOrder (settings->value ("fman_sort_order", 0).toInt()); 
-     
+  sort_mode = settings->value ("fman_sort_mode", 0).toInt();
+  sort_order = Qt::SortOrder (settings->value ("fman_sort_order", 0).toInt());
+
   mymodel = new QStandardItemModel (0, 3, parent);
 
   mymodel->setHeaderData (0, Qt::Horizontal, QObject::tr ("Name"));
   mymodel->setHeaderData (1, Qt::Horizontal, QObject::tr ("Size"));
   mymodel->setHeaderData (2, Qt::Horizontal, QObject::tr ("Modified at"));
 
-  /*
-   
-   QStandardItem *col = mymodel (0);
-    
-   */
-  
   setRootIsDecorated (false);
-
   setAlternatingRowColors (true);
   setAllColumnsShowFocus (true);
-
   setModel (mymodel);
-
   setDragEnabled (true);
-  
 
 #if QT_VERSION >= 0x050000
 
   header()->setSectionResizeMode (QHeaderView::ResizeToContents);
   header()->setSectionsClickable (true);
-   
+
 #else
 
   header()->setResizeMode (QHeaderView::ResizeToContents);
   header()->setClickable (true);
-  
+
 #endif
 
   header()->setSortIndicator (sort_mode, sort_order);
-  header()->setSortIndicatorShown (true);  
+  header()->setSortIndicatorShown (true);
 
   connect (header(), SIGNAL(sortIndicatorChanged(int, Qt::SortOrder)), this, SLOT(header_view_sortIndicatorChanged(int, Qt::SortOrder)));
-  
+
   header()->setStretchLastSection (false);
 
   setSelectionMode (QAbstractItemView::ExtendedSelection);
   setSelectionBehavior (QAbstractItemView::SelectRows);
 
   connect (this, SIGNAL(activated(const QModelIndex &)), this, SLOT(tv_activated(const QModelIndex &)));
-//  connect (this, SIGNAL(doubleClicked(const QModelIndex &)), this, SLOT(tv_activated(const QModelIndex &)));
-
 }
 
 
@@ -312,8 +304,7 @@ void CFMan::cb_fman_currentChanged (const QModelIndex &current, const QModelInde
 
   QString full_path = dir.path() + "/" + item_string;
 
-  if (! is_dir (full_path))
-     emit current_file_changed (full_path, item_string);
+  emit current_file_changed (full_path, item_string);
 }
 
 
@@ -324,8 +315,7 @@ QString CFMan::get_sel_fname()
 
   QModelIndex index = selectionModel()->currentIndex();
   QString item_string = index.data().toString();
-  //return full path
-  return dir.path() + "/" + item_string;
+  return dir.path() + "/" + item_string; //return the full path
 }
 
 
@@ -340,11 +330,11 @@ QStringList CFMan::get_sel_fnames()
   foreach (QModelIndex index, il)
           {
            QString item_string = index.data().toString();
-           if (item_string != "..") 
+           if (item_string != "..")
               {
                QString full_path = dir.path() + "/" + item_string;
                li.append (full_path);
-              } 
+              }
           }
 
   return li;
@@ -356,10 +346,10 @@ void CFMan::refresh()
   QString current;
 
   if (selectionModel()->hasSelection())
-     {    
+     {
       QModelIndex index = selectionModel()->currentIndex();
       current = index.data().toString();
-     } 
+     }
 
   nav (dir.path());
 
@@ -391,29 +381,29 @@ int CFMan::get_sel_index()
 
 void CFMan::mouseMoveEvent (QMouseEvent *event)
 {
-  if (! (event->buttons() & Qt::LeftButton)) 
+  if (! (event->buttons() & Qt::LeftButton))
      return;
 
   QStringList l = get_sel_fnames();
   if (l.size() < 1)
      return;
-  
+
   QDrag *drag = new QDrag (this);
   QMimeData *mimeData = new QMimeData;
- 
+
   QList <QUrl> list;
 
   foreach (QString fn, l)
-           list.append (QUrl::fromLocalFile (fn)); 
+           list.append (QUrl::fromLocalFile (fn));
 
-  mimeData->setUrls (list); 
+  mimeData->setUrls (list);
   drag->setMimeData (mimeData);
- 
-  if (drag->exec (Qt::CopyAction | 
+
+  if (drag->exec (Qt::CopyAction |
                   Qt::MoveAction |
                   Qt::LinkAction) == Qt::MoveAction)
      refresh();
-    
+
   event->accept();
 }
 
@@ -448,7 +438,7 @@ void CFMan::keyPressEvent (QKeyEvent *event)
       return;
      }
 
-     
+
   if (event->key() == Qt::Key_Backspace)
      {
       dir_up();
@@ -456,7 +446,7 @@ void CFMan::keyPressEvent (QKeyEvent *event)
       return;
      }
 
-     
+
   if (event->key() == Qt::Key_Return)
      {
       tv_activated (currentIndex());
@@ -477,7 +467,7 @@ void CFMan::keyPressEvent (QKeyEvent *event)
       event->accept();
       return;
      }
-     
+
 
   if (event->key() == Qt::Key_Down)
      {
@@ -536,7 +526,6 @@ void CFMan::keyPressEvent (QKeyEvent *event)
 void CFMan::drawRow (QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
   if (index.row() == currentIndex().row())
- // if (index.row() == selectionModel()->currentIndex().row())
      {
       QStyleOptionViewItem current_option = option;
       QTreeView::drawRow (painter, current_option, index);
@@ -545,14 +534,13 @@ void CFMan::drawRow (QPainter *painter, const QStyleOptionViewItem &option, cons
       o.rect = option.rect.adjusted(1,1,-1,-1);
       o.state |= QStyle::State_KeyboardFocusChange;
       o.state |= QStyle::State_Item;
-      
+
       //o.backgroundColor = palette().color(QPalette::Background);
       //o.backgroundColor = QColor ("red");
 
       QApplication::style()->drawPrimitive (QStyle::PE_FrameFocusRect, &o, painter);
-      
-      QRect r = option.rect.adjusted(1,1,-1,-1);
-      
+
+      QRect r = option.rect.adjusted (1, 1, -1,-1);
       painter->drawRect (r);
      }
   else
