@@ -36,14 +36,16 @@ public:
   bool terminal_output;
 
   CLogMemo (QWidget *parent = 0);
-  
-  void log (const QString &text);
 
-#if QT_VERSION >= 0x050000
+Q_INVOKABLE void log (const QString &text);
+
+//#if QT_VERSION >= 0x05
+#if QT_VERSION_MAJOR >= 5
+
   void log_terminal (const QString &text);
 #endif
-  
-  void mouseDoubleClickEvent(QMouseEvent *event);  
+
+  void mouseDoubleClickEvent(QMouseEvent *event);
 
 signals:
 
