@@ -2,7 +2,8 @@
 
 #include <QtGlobal>
 
-#if defined(Q_OS_LINUX) || defined(Q_WS_X11) 
+
+#if defined(JOYSTICK_SUPPORTED)
 
 #include <QDebug>
 #include <QApplication>
@@ -23,10 +24,12 @@ CJoystick::CJoystick (uint idn, QObject *upper_link)
   initialized = false;
   number_of_axis = 0;
   number_of_buttons = 0;
+  axis_pressed = false;
+  etype = 0;
 
-  QString filename = "/dev/input/js" + QString::number(id);
+  QString filename = "/dev/input/js" + QString::number (id);
 
-  if (( fd = open (filename.toUtf8().data(), O_NONBLOCK)) == -1)
+  if ((fd = open (filename.toUtf8().data(), O_NONBLOCK)) == -1)
      {
       qDebug() << "Cannot open " << filename;
       return;
@@ -50,6 +53,30 @@ CJoystick::CJoystick (uint idn, QObject *upper_link)
 }
 
 
+void CJoystick::read_joystick_depr()
+{
+  struct JS_DATA_TYPE js;
+  if (read (fd, &js, JS_RETURN) != JS_RETURN)
+     return; //error
+
+  CJoystickAxisEvent *event = new CJoystickAxisEvent (evtJoystickAxis);
+
+  if (js.y != 0)
+     {
+      event->axis = 0;
+      event->value = js.y;
+     }
+
+  if (js.x != 0)
+     {
+      event->axis = 1;
+      event->value = js.x;
+     }
+
+   QApplication::postEvent (receiver, reinterpret_cast<QEvent*>(event));
+}
+
+
 void CJoystick::read_joystick()
 {
   if (! initialized)
@@ -57,12 +84,13 @@ void CJoystick::read_joystick()
 
   struct js_event e;
 
-  while (read (fd, &e, sizeof(e)) > 0) 
+  while (read (fd, &e, sizeof(e)) > 0)
         {
          process_event (e);
         }
 
-  if (errno != EAGAIN) 
+
+  if (errno != EAGAIN)
      {
       qDebug() << "Joystick read error";
       initialized = false;
@@ -72,6 +100,8 @@ void CJoystick::read_joystick()
 
 void CJoystick::process_event (js_event e)
 {
+ // qDebug() << "e.type" << e.type << endl;
+
   if (e.type & JS_EVENT_BUTTON)
      {
       CJoystickButtonEvent *event = new CJoystickButtonEvent (evtJoystickButton);
@@ -82,7 +112,7 @@ void CJoystick::process_event (js_event e)
       QApplication::postEvent (receiver, reinterpret_cast<QEvent*>(event));
      }
   else
-  if (e.type & JS_EVENT_AXIS) 
+  if (e.type & JS_EVENT_AXIS)
      {
       CJoystickAxisEvent *event = new CJoystickAxisEvent (evtJoystickAxis);
 
