@@ -6,7 +6,7 @@
 #include <QtGlobal>
 #include <QObject>
 
-#if defined(Q_OS_LINUX) || defined(Q_WS_X11) 
+#if defined(JOYSTICK_SUPPORTED)
 
 #include <iostream>
 #include <unistd.h>
@@ -51,9 +51,12 @@ public:
 
   QObject *receiver; //link to the object that handle joystick events
 
-  int fd; //joystick file descriptor 
+  int fd; //joystick file descriptor
   uint id; //joystick id
 
+  int etype;
+  bool axis_pressed;
+
   QString description; //joystick text description
   bool initialized;
 
@@ -68,7 +71,10 @@ public:
 public slots:
 
   void read_joystick();
+  void read_joystick_depr();
+
 };
 
+
 #endif
 #endif
