@@ -1,5 +1,5 @@
 /***************************************************************************
- *   2007-2018 by Peter Semiletov                                          *
+ *   2007-2019 by Peter Semiletov                                          *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -37,14 +37,17 @@ some code is taken from Scribus::util.cpp:
 
 #include <QString>
 #include <QMap>
+#include <QDebug>
 
 #include "textproc.h"
 #include "utils.h"
 
 
-
 int str_fuzzy_search (const QString &s, const QString &text_to_find, int start_pos, double q)
 {
+  if (s.isEmpty() || text_to_find.isEmpty())
+     return -1;
+
   int counter;
   int result = -1;
 
@@ -64,11 +67,11 @@ int str_fuzzy_search (const QString &s, const QString &text_to_find, int start_p
                counter++;
 
             if (get_percent ((double)text_to_find.length(), (double)counter) >= q)
-	           {
-	            result = i;
-	            jump = true;
-	            break;
-	           }
+               {
+                result = i;
+                jump = true;
+                break;
+               }
            }
       }
 
@@ -351,7 +354,7 @@ QString qstringlist_process (const QString &s, const QString &params, int mode)
   QStringList sl;
   QStringList l;
   QString result;
-  
+
   if (mode != QSTRL_PROC_FLT_WITH_SORTCASECARE_SEP && mode != QSTRL_PROC_LIST_FLIP_SEP)
      sl = s.split (QChar::ParagraphSeparator);
 
@@ -361,28 +364,28 @@ QString qstringlist_process (const QString &s, const QString &params, int mode)
                                                     {
                                                      if (s.indexOf (params) == -1)
                                                         return s;
-                                                        
+
                                                      QStringList sl = s.split (params);
                                                      sl.sort();
                                                      result = sl.join (params);
                                                      return result;
                                                     };
-                                                    
+
           case QSTRL_PROC_LIST_FLIP_SEP:  {
                                            if (s.indexOf (params) == -1)
                                               return s;
-        
+
                                            QStringList sl = s.split (params);
                                            sl.sort();
-                                                     
+
                                            foreach (QString t, sl)
                                            l.prepend (t);
 
                                            result = l.join (params);
                                            return result;
                                           };
-                                                                                                   
-         
+
+
           case QSTRL_PROC_FLT_WITH_SORTNOCASECARE:
                                                  {
                                                   QMap <QString, QString> map;
@@ -502,7 +505,7 @@ QString int_to_binary (int n)
 /*
 QString int_to_binary (int n)
 {
-  std::bitset<sizeof (int)> bt (n);  
+  std::bitset<sizeof (int)> bt (n);
   return QString::fromStdString (bt.to_string<char,std::string::traits_type,std::string::allocator_type>());
 }
 */
