@@ -81,7 +81,11 @@ Do you want to save your changes?</source>
     <name>CTioReadOnly</name>
     <message>
         <source>saving of this format is not supported</source>
-        <translation>Das Speichern dieses Formats wird nicht unterstützt</translation>
+        <translation type="vanished">Das Speichern dieses Formats wird nicht unterstützt</translation>
+    </message>
+    <message>
+        <source>Saving for this format is not supported</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -142,10 +146,6 @@ Do you want to save your changes?</source>
 Do you want to overwrite?</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Test</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>New</source>
         <translation>Neu</translation>
@@ -832,7 +832,7 @@ Do you want to overwrite?</source>
     </message>
     <message>
         <source>Ready</source>
-        <translation>Fertig</translation>
+        <translation type="vanished">Fertig</translation>
     </message>
     <message>
         <source>%1 is saved</source>
@@ -850,18 +850,10 @@ Do you want to overwrite?</source>
         <source>Icons size</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>UI style</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Word wrap</source>
         <translation>Zeilenumbruch</translation>
     </message>
-    <message>
-        <source>Use wrap setting from highlighting module</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Highlight current line</source>
         <translation>Aktuelle Zeile hervorheben</translation>
@@ -1105,14 +1097,6 @@ opera=opera %s</source>
         <source>size: %1 kbytes</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>created: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>modified: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>bits per sample: %1</source>
         <translation type="unfinished"></translation>
@@ -1813,5 +1797,53 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Cannot save: %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>TEA project template</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>IDE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Build program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clean program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Logmemo font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Syntax highlighting enabled</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FIF at the top (restart needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UI style (restart needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The famous input field. Use for search/replace, function parameters.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Guess encoding!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>last modified: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
