@@ -82,7 +82,11 @@ Voulez-vous sauvegardez vos changements ?</translation>
     <name>CTioReadOnly</name>
     <message>
         <source>saving of this format is not supported</source>
-        <translation>sauvegarder dans ce format n&apos;est pas supporté</translation>
+        <translation type="vanished">sauvegarder dans ce format n&apos;est pas supporté</translation>
+    </message>
+    <message>
+        <source>Saving for this format is not supported</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -162,7 +166,7 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>Test</source>
-        <translation>Test</translation>
+        <translation type="vanished">Test</translation>
     </message>
     <message>
         <source>New</source>
@@ -856,7 +860,7 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>Ready</source>
-        <translation>Prêt</translation>
+        <translation type="vanished">Prêt</translation>
     </message>
     <message>
         <source>%1 is saved</source>
@@ -880,7 +884,7 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>UI style</source>
-        <translation>Modèle de l&apos;IU</translation>
+        <translation type="vanished">Modèle de l&apos;IU</translation>
     </message>
     <message>
         <source>Word wrap</source>
@@ -888,7 +892,7 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>Use wrap setting from highlighting module</source>
-        <translation>Utiliser le retour à la ligne du module de surlignage</translation>
+        <translation type="vanished">Utiliser le retour à la ligne du module de surlignage</translation>
     </message>
     <message>
         <source>Highlight current line</source>
@@ -1149,11 +1153,11 @@ opera=opera %s</source>
     </message>
     <message>
         <source>created: %1</source>
-        <translation>créé : %1</translation>
+        <translation type="vanished">créé : %1</translation>
     </message>
     <message>
         <source>modified: %1</source>
-        <translation>modifié : %1</translation>
+        <translation type="vanished">modifié : %1</translation>
     </message>
     <message>
         <source>bits per sample: %1</source>
@@ -1906,5 +1910,53 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>Cannot save: %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>TEA project template</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>IDE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Build program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clean program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Logmemo font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Syntax highlighting enabled</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FIF at the top (restart needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UI style (restart needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The famous input field. Use for search/replace, function parameters.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Guess encoding!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>last modified: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
