@@ -11,6 +11,8 @@ Peter Semiletov
 #include <QImage>
 
 
+
+
 #include "utils.h"
 
 /* file utils */
@@ -18,14 +20,14 @@ Peter Semiletov
 
 bool file_is_writable (const QString &fname)
 {
-  QFile f (fname);  
+  QFile f (fname);
   return f.isWritable();
 }
 
 
 bool file_is_readable (const QString &fname)
 {
-  QFile f (fname);  
+  QFile f (fname);
   return f.isReadable();
 }
 
@@ -51,11 +53,11 @@ QString change_file_ext (const QString &s, const QString &ext)
   int i = s.lastIndexOf (".");
   if (i == -1)
      return (s + "." + ext);
-  
-  
+
+
   QString r (s);
   r.truncate (++i);
-  
+
   r.append (ext);
   return r;
 }
@@ -140,6 +142,15 @@ QByteArray file_load (const QString &fileName)
 
 /* string/stringlist utils */
 
+
+void strlist_swap (QStringList &l, int a, int b)
+{
+  QString t = l[a];
+  l[a] = l[b];
+  l[b] = t;
+}
+
+
 QString string_between (const QString &source,
                         const QString &sep1,
                         const QString &sep2)
@@ -154,7 +165,7 @@ QString string_between (const QString &source,
      return result;
 
   pos1 += sep1.size();
-  
+
   result = source.mid (pos1, pos2 - pos1);
   return result;
 }
@@ -273,7 +284,7 @@ bool is_image (const QString &filename)
 {
   if (filename.isEmpty())
      return false;
-     
+
   QList <QByteArray> a = QImageReader::supportedImageFormats();
 
   foreach (QByteArray x, a)
@@ -281,7 +292,7 @@ bool is_image (const QString &filename)
            QString t (x.data());
            if (filename.endsWith (t.prepend ("."), Qt::CaseInsensitive))
               return true;
-          } 
+          }
 
   return false;
 }
@@ -290,7 +301,7 @@ bool is_image (const QString &filename)
 QString get_insert_image (const QString &file_name, const QString &full_path, const QString &markup_mode)
 {
   if (! is_image (full_path))
-     return QString();     
+     return QString();
 
   QFileInfo inf (file_name);
   QDir dir (inf.absolutePath());
@@ -350,16 +361,25 @@ void CFilesList::get (const QString &path)
 }
 
 
-CFTypeChecker::CFTypeChecker (const QString &fnames, const QString &exts)
+CFTypeChecker::CFTypeChecker (const QStringList &fnames, const QStringList &exts)
 {
-  lexts = qstring_load (exts).split ("\n");
-  lnames = qstring_load (fnames).split ("\n");
+  lexts = exts;
+  lnames = fnames;
 }
 
 
 bool CFTypeChecker::check (const QString &fname)
 {
-  bool result = lnames.contains (fname.toLower());
+  bool result = false;
+
+#if QT_VERSION >= 0x050000
+  QMimeType mime = db.mimeTypeForFile(fname);
+  if (mime.inherits("text/plain"))
+     result = true;
+#endif
+
+  if (! result)
+  result = lnames.contains (fname.toLower());
   if (! result)
      {
       QString ext = file_get_ext (fname);
@@ -368,3 +388,13 @@ bool CFTypeChecker::check (const QString &fname)
 
   return result;
 }
+
+
+QStringList CFTypeChecker::get_supported_exts()
+{
+  QStringList l;
+
+  l += lexts;
+  l.append ("txt");
+  return l;
+}
