@@ -12,6 +12,11 @@ Peter Semiletov
 #include <QStringList>
 
 
+#if QT_VERSION >= 0x050000
+#include <QMimeDatabase>
+#endif
+
+
 class CFilesList: public QObject
 {
 public:
@@ -30,8 +35,13 @@ public:
   QStringList lexts;
   QStringList lnames;
 
-  CFTypeChecker (const QString &fnames, const QString &exts);
+#if QT_VERSION >= 0x050000
+  QMimeDatabase db;
+#endif
+
+  CFTypeChecker (const QStringList &fnames, const QStringList &exts);
   bool check (const QString &fname);
+  QStringList get_supported_exts();
 };
 
 
@@ -63,6 +73,7 @@ QString string_between (const QString &source, const QString &sep1, const QStrin
 bool char_is_bad (const QChar &c);
 void qstring_list_print (const QStringList &l);
 QStringList bytearray_to_stringlist (QList<QByteArray> a);
+void strlist_swap (QStringList &l, int a, int b);
 
 
 /* hash utils */
@@ -120,5 +131,4 @@ inline QString get_file_path (const QString &fileName)
   return QFileInfo (fileName).absolutePath();
 }
 
-
 #endif
